@@ -125,7 +125,9 @@ void PlaceTreeModelTest::testListPlaces()
 {
     PlaceTreeModel model(0);
 
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 41, 0)
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 45, 0)
+    QCOMPARE(model.rowCount(), 8);
+#elif KIO_VERSION >= QT_VERSION_CHECK(5, 41, 0)
     QCOMPARE(model.rowCount(), 10);
 #else
     QCOMPARE(model.rowCount(), 2);
